@@ -1,3 +1,5 @@
+use boolean;
+
 sub stdtests {
     return (
     # array
@@ -27,41 +29,41 @@ sub stdtests {
     {category=>'hash', parse_error=>qr/invalid syntax/i, text=>'a=>1'},
 
     # comparison equal
-    {category=>'comparison equal num', text=>'1 == 2', result=>''},
-    {category=>'comparison equal num', text=>'1 == 1', result=>'1'},
-    {category=>'comparison equal num', text=>'1 != 2', result=>'1'},
-    {category=>'comparison equal num', text=>'1 != 1', result=>''},
-    {category=>'comparison equal num', text=>'0 == 0', result=>'1'},
-    {category=>'comparison equal num', text=>'3 <=> 4', result=>'-1'},
-    {category=>'comparison equal num', text=>'4 <=> 3', result=>'1'},
-    {category=>'comparison equal num', text=>'3 <=> 3', result=>'0'},
-    {category=>'comparison equal num', text=>'3 <=> 3', result=>'0'},
+    {category=>'comparison equal num', text=>'1 == 2', result=>false},
+    {category=>'comparison equal num', text=>'1 == 1', result=>true},
+    {category=>'comparison equal num', text=>'1 != 2', result=>true},
+    {category=>'comparison equal num', text=>'1 != 1', result=>false},
+    {category=>'comparison equal num', text=>'0 == 0', result=>true},
+    {category=>'comparison equal num', text=>'3 <=> 4', result=>-1},
+    {category=>'comparison equal num', text=>'4 <=> 3', result=>1},
+    {category=>'comparison equal num', text=>'3 <=> 3', result=>0},
+    {category=>'comparison equal num', text=>'3 <=> 3', result=>0},
 
-    {category=>'comparison equal chained', text=>"0 == 1 == 0", result=>''},
-    {category=>'comparison equal chained', text=>"2 == 2 == 2", result=>'1'},
-    {category=>'comparison equal chained', text=>"0 eq 1 eq ''", result=>''},
-    {category=>'comparison equal chained', text=>"2 != 3 != 1", result=>'1'},
+    {category=>'comparison equal chained', text=>"0 == 1 == 0", result=>false},
+    {category=>'comparison equal chained', text=>"2 == 2 == 2", result=>true},
+    {category=>'comparison equal chained', text=>"0 eq 1 eq ''", result=>false},
+    {category=>'comparison equal chained', text=>"2 != 3 != 1", result=>true},
 
-    {category=>'comparison equal str', text=>'"" eq ""', result=>'1'},
-    {category=>'comparison equal str', text=>'"aa" cmp "ab"', result=>'-1'},
+    {category=>'comparison equal str', text=>'"" eq ""', result=>true},
+    {category=>'comparison equal str', text=>'"aa" cmp "ab"', result=>-1},
 
     # comparison less_greater
-    {category=>'comparison less_greater', text=>'1<2', result=>'1'},
-    {category=>'comparison less_greater', text=>'2<2', result=>''},
-    {category=>'comparison less_greater', text=>'3<2', result=>''},
-    {category=>'comparison less_greater', text=>'1 <= 2', result=>'1'},
-    {category=>'comparison less_greater', text=>'1 <= 1', result=>'1'},
-    {category=>'comparison less_greater', text=>'3 <= 2', result=>''},
-    {category=>'comparison less_greater', text=>'1>2', result=>''},
-    {category=>'comparison less_greater', text=>'2>2', result=>''},
-    {category=>'comparison less_greater', text=>'3>2', result=>'1'},
-    {category=>'comparison less_greater', text=>'1 >= 2', result=>''},
-    {category=>'comparison less_greater', text=>'1 >= 1', result=>'1'},
-    {category=>'comparison less_greater', text=>'3 >= 2', result=>'1'},
+    {category=>'comparison less_greater', text=>'1<2', result=>true},
+    {category=>'comparison less_greater', text=>'2<2', result=>false},
+    {category=>'comparison less_greater', text=>'3<2', result=>false},
+    {category=>'comparison less_greater', text=>'1 <= 2', result=>true},
+    {category=>'comparison less_greater', text=>'1 <= 1', result=>true},
+    {category=>'comparison less_greater', text=>'3 <= 2', result=>false},
+    {category=>'comparison less_greater', text=>'1>2', result=>false},
+    {category=>'comparison less_greater', text=>'2>2', result=>false},
+    {category=>'comparison less_greater', text=>'3>2', result=>true},
+    {category=>'comparison less_greater', text=>'1 >= 2', result=>false},
+    {category=>'comparison less_greater', text=>'1 >= 1', result=>true},
+    {category=>'comparison less_greater', text=>'3 >= 2', result=>true},
 
-    {category=>'comparison less_greater chained', text=>'3 > 2 > 1', result=>'1'},
-    {category=>'comparison less_greater chained', text=>'2 > 3 > 1', result=>''},
-    {category=>'comparison less_greater chained', text=>'2 > 3 < 1', result=>''},
+    {category=>'comparison less_greater chained', text=>'3 > 2 > 1', result=>true},
+    {category=>'comparison less_greater chained', text=>'2 > 3 > 1', result=>false},
+    {category=>'comparison less_greater chained', text=>'2 > 3 < 1', result=>false},
 
     {category=>'comparison less_greater', parse_error=>qr/invalid syntax/i, text=>'>'},
     {category=>'comparison less_greater', parse_error=>qr/invalid syntax/i, text=>'1 >'},
@@ -72,17 +74,17 @@ sub stdtests {
     # and
     {category=>'and', text=>'1 && 2', result=>'2'},
     {category=>'and', text=>'1 && 0', result=>'0'},
-    {category=>'and', text=>'1 > 1 && 1 >= 1', result=>''},
-    {category=>'and chained', text=>'1 > 1 && 1 > 1', result=>''},
+    {category=>'and', text=>'1 > 1 && 1 >= 1', result=>false},
+    {category=>'and chained', text=>'1 > 1 && 1 > 1', result=>false},
 
     # or & xor
-    {category=>'or_xor', text=>'1 || 2', result=>'1'},
-    {category=>'or_xor', text=>'1 || 0', result=>'1'},
-    {category=>'or_xor', text=>'1 > 1 || 1 >= 1', result=>'1'},
-    {category=>'or_xor', text=>'1 > 1 || 1 > 1', result=>''},
-    {category=>'or_xor', text=>'1 // 2', result=>'1'},
-    {category=>'or_xor', text=>'1 // undef', result=>'1'},
-    {category=>'or_xor', text=>'undef // 2', result=>'2'},
+    {category=>'or_xor', text=>'1 || 2', result=>true},
+    {category=>'or_xor', text=>'1 || 0', result=>true},
+    {category=>'or_xor', text=>'1 > 1 || 1 >= 1', result=>true},
+    {category=>'or_xor', text=>'1 > 1 || 1 > 1', result=>false},
+    {category=>'or_xor', text=>'1 // 2', result=>1},
+    {category=>'or_xor', text=>'1 // undef', result=>1},
+    {category=>'or_xor', text=>'undef // 2', result=>2},
     {category=>'or_xor', text=>'undef // undef', result=>undef},
 
     # add
@@ -110,12 +112,12 @@ sub stdtests {
     {category=>'power', text=>'2**4**2', result=>'65536'},
 
     # unary
-    {category=>'unary', text=>'!2', result=>''},
-    {category=>'unary', text=>'!!2', result=>'1'},
-    {category=>'unary', text=>'!!2', result=>'1'},
+    {category=>'unary', text=>'!2', result=>false},
+    {category=>'unary', text=>'!!2', result=>true},
+    {category=>'unary', text=>'!!2', result=>true},
     {category=>'unary', text=>'--2', result=>2},
     {category=>'unary', text=>'---2', result=>-2},
-    {category=>'unary', text=>'~2', result=>~2},
+    {category=>'unary', text=>'~2', result=>~2, js_result=>(-(2)-1)}, # js's bitwise NOT is a bit peculiar
 
     # bitwise
     {category=>'bit', text=>'3|5', result=>'7'},
@@ -129,8 +131,8 @@ sub stdtests {
 
     # term:literal
     {category=>'undef', text=>'undef', result=>undef},
-    {category=>'true', text=>'true', result=>1},
-    {category=>'false', text=>'false', result=>''},
+    {category=>'true', text=>'true', result=>true},
+    {category=>'false', text=>'false', result=>false},
     {category=>'num', text=>'1', result=>'1'},
     {category=>'num', text=>'1.1', result=>'1.1'},
     {category=>'dquotestr', text=>q("satu ' dua"), result=>"satu ' dua"},
@@ -168,22 +170,22 @@ sub stdtests {
     {category=>'subscripting', text => '{a=>[10, 20]}["a"][1]', result=>20},
     #{category=>'subscripting', parse_error=>qr/subscript/i, text => '1[1]'}, # currently doesn't work, RG bug?
 
-    {category=>'func', text=>'length("str")', result=>'3'},
-    {category=>'func', parse_error=>qr/invalid syntax/i, text => 'length'},
-    {category=>'func', parse_error=>qr/invalid syntax/i, text => 'length "str"'},
-    {category=>'func', text=>'length("s" . "tr")', result=>'3'},
-    {category=>'func', text=>'ceil(rand())+floor(rand()*rand())', result=>'1'},
+    {category=>'func', text=>'floor(3.6)', result=>'3'},
+    {category=>'func', parse_error=>qr/invalid syntax/i, text => 'floor'},
+    {category=>'func', parse_error=>qr/invalid syntax/i, text => 'floor 3.6'},
+    {category=>'func', text=>'floor(3.6 + 0.4)', result=>4},
+    {category=>'func', text=>'ceil(0.7)+floor(0.3+0.6)', result=>1},
     #{category=>'func', run_error => qr/unknown func|undefined sub/i, text=>'foo(1)', result=>'1'}, # BUG in RG? causes error: Can't use an undefined value as an ARRAY reference at (re_eval 252) line 2.
 
     # map=7
     {category=>'map', has_subexpr=>1, text=>'map {}, []', parse_error=>qr/invalid syntax/i}, # lack parenthesis
     {category=>'map', has_subexpr=>1, text=>'map({1<}, [])', parse_error=>qr/invalid syntax/i}, # invalid subexpression
 
-    {category=>'map', has_subexpr=>1, text=>'map()', compiler_run_error=>qr/not enough arg/i},
+    {category=>'map', has_subexpr=>1, text=>'map()', compiler_run_error=>qr/not enough arg/i, js_compiler_run_error=>qr/javascript error/i},
     #{category=>'map', has_subexpr=>1, text=>'map({}, [])'}, # empty subexpression. won't be parsed as map(), but ok.
     #{category=>'map', has_subexpr=>1, text=>'map(1, [])'}, # not subexpression. won't be parsed as map(), but ok. but in perl result will be 1.
 
-    {category=>'map', has_subexpr=>1, text=>'map({$_*2}, {})', compiler_run_error=>qr/syntax error|unmatched right/i}, # although doesn't make sense, parses
+    {category=>'map', has_subexpr=>1, text=>'map({$_*2}, {})', compiler_run_error=>qr/syntax error|unmatched right/i, js_compiler_run_error=>qr/javascript error/i}, # although doesn't make sense, parses
     {category=>'map', has_subexpr=>1, text=>'map({$_*2}, [])', result=>[]},
     {category=>'map', has_subexpr=>1, text=>'map({$_*2}, [1,2,3])', result=>[2, 4, 6]},
     {category=>'map', has_subexpr=>1, text=>'map({ map({$_+1}, [$_])[0] }, [1,2,3])', result=>[2, 3, 4]}, # nested map
@@ -192,11 +194,11 @@ sub stdtests {
     {category=>'grep', has_subexpr=>1, text=>'grep {}, []', parse_error=>qr/invalid syntax/i}, # lack parenthesis
     {category=>'grep', has_subexpr=>1, text=>'grep({1<}, [])', parse_error=>qr/invalid syntax/i}, # invalid subexpression
 
-    {category=>'grep', has_subexpr=>1,  text=>'grep()', compiler_run_error=>qr/not enough arg/i}, # lack arguments. won't be parsed as grep(), but ok
+    {category=>'grep', has_subexpr=>1,  text=>'grep()', compiler_run_error=>qr/not enough arg/i, js_compiler_run_error=>qr/javascript error/i}, # lack arguments. won't be parsed as grep(), but ok
     #{category=>'grep', has_subexpr=>1, text=>'grep({}, [])'}, # empty subexpression. won't be parsed as grep(), but ok
     #{category=>'grep', has_subexpr=>1, text=>'grep(1, [])'}, # not subexpression. won't be parsed as grep(), but ok
 
-    {category=>'grep', has_subexpr=>1, text=>'grep({$_>1}, {})', compiler_run_error=>qr/syntax error|unmatched right/}, # although doesn't make sense, parses
+    {category=>'grep', has_subexpr=>1, text=>'grep({$_>1}, {})', compiler_run_error=>qr/syntax error|unmatched right/i, js_compiler_run_error=>qr/javascript error/i}, # although doesn't make sense, parses
     {category=>'grep', has_subexpr=>1, text=>'grep({$_>1}, [])', result=>[]},
     {category=>'grep', has_subexpr=>1, text=>'grep({$_>1}, [1,2,3])', result=>[2, 3]},
     {category=>'grep', has_subexpr=>1, text=>'grep({ grep({$_ > 1}, [$_])[0] }, [1,2,3])', result=>[2, 3]}, # nested grep
@@ -205,11 +207,11 @@ sub stdtests {
     {category=>'usort', has_subexpr=>1, text=>'usort {}, []', parse_error=>qr/invalid syntax/i}, # lack parenthesis
     {category=>'usort', has_subexpr=>1, text=>'usort({1<}, [])', parse_error=>qr/invalid syntax/i}, # invalid subexpression
 
-    {category=>'usort', has_subexpr=>1, text=>'usort()', compiler_run_error=>qr/undefined sub.+usort/i}, # lack arguments. won't be parsed as usort(), but ok
+    {category=>'usort', has_subexpr=>1, text=>'usort()', compiler_run_error=>qr/undefined sub.+usort/i, js_compiler_run_error=>qr/javascript error/i}, # lack arguments. won't be parsed as usort(), but ok
     #{category=>'usort', has_subexpr=>1, text=>'usort({}, [])'}, # empty subexpression. won't be parsed as usort(), but ok
     #{category=>'usort', has_subexpr=>1, text=>'usort(1, [])'}, # not subexpression. won't be parsed as usort(), but ok
 
-    {category=>'usort', has_subexpr=>1, text=>'usort({uc($a) cmp uc($b)}, {})', compiler_run_error=>qr/syntax error|unmatched right/i}, # although doesn't make sense, parses
+    {category=>'usort', has_subexpr=>1, text=>'usort({uc($a) cmp uc($b)}, {})', compiler_run_error=>qr/syntax error|unmatched right/i, js_compiler_run_error=>qr/javascript error/i}, # although doesn't make sense, parses
     {category=>'usort', has_subexpr=>1, text=>'usort({uc($a) cmp uc($b)}, [])', result=>[]},
     {category=>'usort', has_subexpr=>1, text=>'usort({uc($a) cmp uc($b)}, ["B", "a", "C"])', result=>["a", "B", "C"]},
     {category=>'usort', has_subexpr=>1, text=>'usort({ usort({$b <=> $a}, [$a])[0] <=> usort({$b<=>$a}, [$b])[0] }, [3, 2, 1])', result=>[1, 2, 3]}, # nested usort
